# frozen_string_literal: true

require 'cht-chaphql'
require 'cht-chaphql/graphql_formatters'

DATA_QUERY_INTERNAL_FMTRS =
  YAML.load_file(File.join(__dir__, '../helpers/formatters.yml'))

# module for data-query-internal
module ChtApitestDataQueryInternal
  include Chaphql
  include Chaphql::GraphQLHelpers

  # module for your shortcuts
  module DataQueryInternalHelpers
    def via_public
      %w[staging canary prod].include?(getenv)
    end

    def auth_service
      LocalAuthService.new(via_public: via_public)
    end
    # insertion point for shortcuts
    # end of shortcut insertion
  end

  # class for your service
  class DataQueryInternalService < ChtNgService
    include RSpec::Matchers

    DATA_QUERY_INTERNAL_DEFAULTS = {
      name: 'DataQueryInternal',
      default_namespace: 'data-query-internal',
      service_name: 'data-query-internal',
      pr_parent: 'data-query-internal',
      formatters: DATA_QUERY_INTERNAL_FMTRS['formatters'],
      v2_checkers: DATA_QUERY_INTERNAL_FMTRS['v2_checkers']
    }.freeze
    def initialize(args = {})
      super(args.merge(DATA_QUERY_INTERNAL_DEFAULTS))
    end
  end

  # class for api-proxy support of data-query-internal service
  class ApiProxyDataQueryInternal < ChtNgService
    include RSpec::Matchers

    API_PROXY_DEFAULTS = {
      name: 'ApiProxyDataQueryInternal',
      default_namespace: 'api-proxy',
      service_name: 'api-proxy',
      pr_parent: 'api-proxy',
      formatters: DATA_QUERY_INTERNAL_FMTRS['formatters'],
      v2_checkers: DATA_QUERY_INTERNAL_FMTRS['v2_checkers']
    }.freeze
    def initialize(args = {})
      super(args.merge(API_PROXY_DEFAULTS))
    end
  end
end
